@@ -1,7 +1,5 @@
 package Business::OnlinePayment::Ogone;
-BEGIN {
-  $Business::OnlinePayment::Ogone::AUTHORITY = 'cpan:ESSELENS';
-}
+our $AUTHORITY = 'cpan:ESSELENS';
 use parent 'Business::OnlinePayment::HTTPS';
 use strict; # keep Perl::Critic happy over common::sense;
 use common::sense;
@@ -271,6 +269,7 @@ sub submit {
         if ( $xml->{STATUS} == 5  ) { $self->is_success(1) } # authorization accepted
         if ( $xml->{STATUS} == 9  ) { $self->is_success(1) } # payment accepted
         if ( $xml->{STATUS} == 91 ) { $self->is_success(1) } # partial payment accepted
+        if ( $xml->{STATUS} == 61 ) { $self->is_success(1) } # Author. deletion waiting
         if ( $xml->{STATUS} == 2 ) { $self->failure_status('refused') } # authorization refused
         if ( $xml->{STATUS} == 0 && $xml->{NCERROR} eq '50001134' ) { $self->failure_status('declined') } # 3d secure wrong identification
         if ( $xml->{STATUS} == 0 && $xml->{NCERRORPLUS} =~ m/status \(91\)/ ) { 
@@ -514,14 +513,14 @@ code as a reference to what exactly is required depending on the parameters.
 
 =head2 content() examples
 
-=head3 example B<authorize only> request: requests a claim on an amount of money [RES] (and creates an alias)
+=head3 example B<authorization only> request: requests a claim on an amount of money [RES] (and creates an alias)
 
     my %auth = ( pspid => 'fred', login => 'bedrock_api', password => 'fl1nst0ne' );
 
     my $id = $session->get('orderid');
     my $res = new Business::OnlinePayment('Ogone', %auth);
 
-    $res->content( invoice_number => $id, action => 'authorize only', alias => 'wilma flinstone',  ... );
+    $res->content( invoice_number => $id, action => 'authorization only', alias => 'wilma flinstone',  ... );
     $res->submit();
 
     if ( $res->is_success() ) {
@@ -592,33 +591,33 @@ code as a reference to what exactly is required depending on the parameters.
 
 =head1 STATE DIAGRAMS
 
-=head2 Authorize Only
+=head2 Authorization Only
 
          Client                                 Ogone HTTPS      Bank
       ------------------------------------------------------------------------
 
-      1    +---|Authorize Only| orderID=1----------->. [RES]        
-                                                     |              
-      2    *<---STATUS=5 ----------------------------'                    
+      1    +---|Authorization Only| orderID=1----------->. [RES]
+                                                         |
+      2    *<---STATUS=5 ---------0000-------------------'
 
 =over 4
 
-=item B<1> submit authorize only request usin RES operation with orderID=1. This will reserve the money on the credit card.
+=item B<1> submit authorization only request usin RES operation with orderID=1. This will reserve the money on the credit card.
 
 =item B<2> STATUS=5 indicates the authorization succeeded.
 
 =back
   
-=head2 Post Authorize
+=head2 Post Authorization
 
          Client                                 Ogone HTTPS      Bank
       ------------------------------------------------------------------------
 
-      1    +---|Post Authorize| orderID=1----------->. [SAL] 
-                                                     |
-      2    *<---STATUS=91 PAYID=.. PAYIDSUB=.. ------+ (processing)
-                                                     |
-      3                                              `----------->.
+      1    +---|Post Authorization| orderID=1----------->. [SAL] 
+                                                         |
+      2    *<---STATUS=91 PAYID=.. PAYIDSUB=.. ----------+ (processing)
+                                                         |
+      3                                                  `------->.
                                                                   | (processed) +$
       4                                     STATUS=9 .<-----------'
 
